#GENERATION OF RESULTS IN SECTION 3.2.: "Foraging parameters"


#Load required R package
library(lmerTest)




#ANALYSIS OF FEEDING FREQUENCY PER HOUR

#Load data
Feeding.frequency <- read.table()


#Convert column "Year" to character
Feeding.frequency$Year <- as.character(Feeding.frequency$Year)


#Calculate mean and standard deviation of feeding frequency per hour
mean(Feeding.frequency$Frequency_visits_per_h)
sd(Feeding.frequency$Frequency_visits_per_h)


#Check for correlation of predictor variables
Correlations_Feeding_frequency <- Feeding.frequency[,c("Breeding_season_d", "Chick_age_d", "Daytime_min", "Temperature_C", "Wind_km_h", "Radio_tagging", "Year")]
Correlations_Feeding_frequency$Year[Correlations_Feeding_frequency$Year == "2018"] <- 1
Correlations_Feeding_frequency$Year[Correlations_Feeding_frequency$Year == "2019"] <- 0
Correlations_Feeding_frequency$Radio_tagging[Correlations_Feeding_frequency$Radio_tagging == "yes"] <- 1
Correlations_Feeding_frequency$Radio_tagging[Correlations_Feeding_frequency$Radio_tagging == "no"] <- 0
Correlations_Feeding_frequency$Year <- as.numeric(Correlations_Feeding_frequency$Year)
Correlations_Feeding_frequency$Radio_tagging <- as.numeric(Correlations_Feeding_frequency$Radio_tagging)
cor(Correlations_Feeding_frequency)


#Run LMM
Model.feeding.frequency.hour <- lmer(Frequency_visits_per_h ~ Breeding_season_d  + Chick_age_d + Daytime_min + Temperature_C + Wind_km_h + Radio_tagging + Year + (1|Nest_id), weights = Weighting_factor_analysis, data = Feeding.frequency)
summary(Model.feeding.frequency.hour)




#ANALYSIS OF FEEDING FREQUENCY PER HOUR AND CHICK

#Calculate mean and standard deviation of feeding frequency per hour and chick
mean(Feeding.frequency$Frequency_visits_per_h_chick)
sd(Feeding.frequency$Frequency_visits_per_h_chick)


#Run LMM
Model.feeding.frequency.hour.chick <- lmer(Frequency_visits_per_h_chick ~ Breeding_season_d  + Chick_age_d + Daytime_min + Temperature_C + Wind_km_h + Radio_tagging + Year + (1|Nest_id), weights = Weighting_factor_analysis, data = Feeding.frequency)
summary(Model.feeding.frequency.hour.chick)




#ANALYSIS OF DISTANCE FLOWN TO FORAGING HABITAT

#Load data
Distance <- read.table()


#Convert column "Year" to character
Distance$Year <- as.character(Distance$Year)


#Calculate mean and standard deviation of distance flown to foraging habitat
mean(Distance$Distance_m)
sd(Distance$Distance_m)


#Check for correlation of predictor variables
Correlations_Distance <- Distance[,c("Breeding_season_d", "Chick_age_d", "Daytime_min", "Temperature_C", "Wind_km_h", "Radio_tagging", "Year")]
Correlations_Distance$Year[Correlations_Distance$Year == "2018"] <- 1
Correlations_Distance$Year[Correlations_Distance$Year == "2019"] <- 0
Correlations_Distance$Radio_tagging[Correlations_Distance$Radio_tagging == "yes"] <- 1
Correlations_Distance$Radio_tagging[Correlations_Distance$Radio_tagging == "no"] <- 0
Correlations_Distance$Year <- as.numeric(Correlations_Distance$Year)
Correlations_Distance$Radio_tagging <- as.numeric(Correlations_Distance$Radio_tagging)
cor(Correlations_Distance)


#Run LMM
Model.Distance <- lmer(Distance_m ~ Breeding_season_d  + Chick_age_d + Daytime_min + Temperature_C + Wind_km_h + Radio_tagging  + Year  + (1|Nest_id), weights = Weighting_factor_analysis, data = Distance)
summary(Model.Distance)




#ANALYSIS OF AREA SEARCHED FOR FOOD

#Load data
MCP <- read.table()


#Convert column "Year" to character
MCP$Year <- as.character(MCP$Year)


#Calculate mean and standard deviation of area searched for food
mean(MCP$MCP95_ha)
sd(MCP$MCP95_ha)


#Check for correlation of predictor variables
Correlations_MCP <- MCP[,c("Hatching_d", "Observations_before_noon_percentage", "Mean_temperature_C", "Mean_wind_km_h", "Radio_tagging", "Year")]
Correlations_MCP$Year[Correlations_MCP$Year == "2018"] <- 1
Correlations_MCP$Year[Correlations_MCP$Year == "2019"] <- 0
Correlations_MCP$Radio_tagging[Correlations_MCP$Radio_tagging == "yes"] <- 1
Correlations_MCP$Radio_tagging[Correlations_MCP$Radio_tagging == "no"] <- 0
Correlations_MCP$Year <- as.numeric(Correlations_MCP$Year)
Correlations_MCP$Radio_tagging <- as.numeric(Correlations_MCP$Radio_tagging)
cor(Correlations_MCP)


#Run LM
Model.MCP <- lm(Minimum_convex_polygon_95_hectare ~ Hatching_d + Observations_before_noon_percentage + Mean_temperature_C + Mean_wind_km_h + Radio_tagging  + Year, data = MCP)
summary(Model.MCP)

