#GENERATION OF RESULTS IN SECTION 3.1.1.: "Influence of prey biomass and diversity, vegetation structure, and foraging distance"


#Load required R package
library(mgcv)


#Load data 
Dataset.habitat.selection <- read.table() 


#Convert characters to factors
Dataset.habitat.selection$Nest_id <- as.factor(as.character(Dataset.habitat.selection$Nest_id))
Dataset.habitat.selection$Data_point <- as.factor(as.character(Dataset.habitat.selection$Data_point))


#Use pseudo-absence data as reference in GAMM analysis
Dataset.habitat.selection$Data_point <- relevel(Dataset.habitat.selection$Data_point, ref="pseudo_absence")


#Check for correlation of predictor variables
cor(na.omit(Dataset.habitat.selection[, c("Vegetation_cover_percentage", "Arthropod_biomass_g_per_m2", "Insect_diversity_Shannon_index", "Distance_m")]))


#Run GAMM              
Model.habitat.selection <- gam(formula = Data_point ~ s(Vegetation_cover_percentage) + s(Arthropod_biomass_g_per_m2) + s(Insect_diversity_Shannon_index) + s(Distance_m) + s(Nest_id, bs = "re"), family = "binomial", weights = Weighting_factor_analysis, data = Dataset.habitat.selection, method = "ML")
summary(Model.habitat.selection)


#Run analysis of relative variable importance
set.seed(14)
Variables <- Dataset.habitat.selection[, c("Vegetation_cover_percentage", "Arthropod_biomass_g_per_m2", "Insect_diversity_Shannon_index", "Distance_m", "Nest_id")]
Iter <- 100
Imp <- matrix(NA, Iter, 5)
Variables1 <- Variables
Names <- c("Vegetation_cover_percentage", "Arthropod_biomass_g_per_m2", "Insect_diversity_Shannon_index", "Distance_m", "Nest_id")
Pred <- predict(Model.habitat.selection, Variables, type = "response")

for(i in 1:Iter){
  for(j in 1:length(Names) ){
    Variables1 <- Variables
    Variables1[, Names[j]] <- sample(Variables[, Names[j]])
    Pred1 <- predict(Model.habitat.selection, Variables1, type = "response")
    Imp[i, j] <- 1-cor(Pred, Pred1, use = "complete.obs")
    print(i)
  }}

colnames(Imp) <- Names
Relative.variable.importance <- data.frame(t(colMeans(Imp/rowSums(Imp)*100)))

