#GENERATION OF RESULTS OF GLMMs IN SECTION 3.1.2.: "Overall and time-dependent use of habitat types"


#Load required R package
library(lme4)


#Load data 
Dataset.GLMM <- read.table() 


#Convert column "Year" to character
Dataset.GLMM$Year <- as.character(Dataset.GLMM$Year)




#MODEL: WINTER WHEAT

#Create dataset
Dataset.winter.wheat <- subset(Dataset.GLMM, subset = Dataset.GLMM$Winter_wheat_percentage > 0)
Dataset.winter.wheat$Foraging_location_winter_wheat <- ifelse(Dataset.winter.wheat$Habitat_foraging_location == "winter_wheat", 1, 0)


#Assign equal weights to nests per day of observation
Unique.observations <- unique(paste(Dataset.winter.wheat$Nest_id, Dataset.winter.wheat$Breeding_season_d))
Dataset.winter.wheat$Weighting_factor_analysis <- rep(NA, length(Dataset.winter.wheat$Nest_id))
for(i in Unique.observations){
  w <- which(paste(Dataset.winter.wheat$Nest_id, Dataset.winter.wheat$Breeding_season_d) == i)
  Dataset.winter.wheat$Weighting_factor_analysis[w] <- length(Dataset.winter.wheat$Weighting_factor_analysis)/length(Unique.observations)/length(w)}


#Check for correlation of predictor variables
Correlations_Winter_wheat <- Dataset.winter.wheat[,c("Year", "Breeding_season_d", "Winter_wheat_percentage")]
Correlations_Winter_wheat$Year[Correlations_Winter_wheat$Year == "2018"] <- 1
Correlations_Winter_wheat$Year[Correlations_Winter_wheat$Year == "2019"] <- 0
Correlations_Winter_wheat$Year <- as.numeric(Correlations_Winter_wheat$Year)
cor(Correlations_Winter_wheat)


#Run GLMM
Model.winter.wheat <- glmer(Foraging_location_winter_wheat ~ Breeding_season_d + Winter_wheat_percentage  + Year + (1|Nest_id), family = "binomial"(link = "logit"), weights = Weighting_factor_analysis, data = Dataset.winter.wheat)
summary(Model.winter.wheat)




#MODEL: SUGAR BEET

#Create dataset
Dataset.sugar.beet <- subset(Dataset.GLMM, subset = Dataset.GLMM$Sugar_beet_percentage > 0)
Dataset.sugar.beet$Foraging_location_sugar_beet <- ifelse(Dataset.sugar.beet$Habitat_foraging_location == "sugar_beet", 1, 0)


#Assign equal weights to nests per day of observation
Unique.observations <- unique(paste(Dataset.sugar.beet$Nest_id, Dataset.sugar.beet$Breeding_season_d))
Dataset.sugar.beet$Weighting_factor_analysis <- rep(NA, length(Dataset.sugar.beet$Nest_id))
for(i in Unique.observations){
  w <- which(paste(Dataset.sugar.beet$Nest_id, Dataset.sugar.beet$Breeding_season_d) == i)
  Dataset.sugar.beet$Weighting_factor_analysis[w] <- length(Dataset.sugar.beet$Weighting_factor_analysis)/length(Unique.observations)/length(w)}


#Check for correlation of predictor variables
Correlations_Sugar_beet <- Dataset.sugar.beet[,c("Year", "Breeding_season_d", "Sugar_beet_percentage")]
Correlations_Sugar_beet$Year[Correlations_Sugar_beet$Year == "2018"] <- 1
Correlations_Sugar_beet$Year[Correlations_Sugar_beet$Year == "2019"] <- 0
Correlations_Sugar_beet$Year <- as.numeric(Correlations_Sugar_beet$Year)
cor(Correlations_Sugar_beet)


#Run GLMM
Model.sugar.beet <- glmer(Foraging_location_sugar_beet ~ Breeding_season_d + Sugar_beet_percentage + Year + (1|Nest_id), family = "binomial"(link = "logit"), weights = Weighting_factor_analysis, data = Dataset.sugar.beet)
summary(Model.sugar.beet)




#MODEL: CORN

#Create dataset
Dataset.corn <- subset(Dataset.GLMM, subset = Dataset.GLMM$Corn_percentage > 0)
Dataset.corn$Foraging_location_corn <- ifelse(Dataset.corn$Habitat_foraging_location == "corn", 1, 0)


#Assign equal weights to nests per day of observation
Unique.observations <- unique(paste(Dataset.corn$Nest_id, Dataset.corn$Breeding_season_d))
Dataset.corn$Weighting_factor_analysis <- rep(NA, length(Dataset.corn$Nest_id))
for(i in Unique.observations){
  w <- which(paste(Dataset.corn$Nest_id, Dataset.corn$Breeding_season_d) == i)
  Dataset.corn$Weighting_factor_analysis[w] <- length(Dataset.corn$Weighting_factor_analysis)/length(Unique.observations)/length(w)}


#Check for correlation of predictor variables
Correlations_Corn <- Dataset.corn[,c("Year", "Breeding_season_d", "Corn_percentage")]
Correlations_Corn$Year[Correlations_Corn$Year == "2018"] <- 1
Correlations_Corn$Year[Correlations_Corn$Year == "2019"] <- 0
Correlations_Corn$Year <- as.numeric(Correlations_Corn$Year)
cor(Correlations_Corn)


#Run GLMM
Model.corn <- glmer(Foraging_location_corn ~ Breeding_season_d + Corn_percentage + Year + (1|Nest_id), family = "binomial"(link = "logit"), weights = Weighting_factor_analysis, data = Dataset.corn)
summary(Model.corn)




#MODEL: ANNUAL FLOWER STRIP

#Create dataset
Dataset.annual.flower.strip <- subset(Dataset.GLMM, subset = Dataset.GLMM$Annual_flower_strip_percentage > 0)
Dataset.annual.flower.strip$Foraging_location_annual_flower_strip <- ifelse(Dataset.annual.flower.strip$Habitat_foraging_location == "annual_flower_strip", 1, 0)


#Assign equal weights to nests per day of observation
Unique.observations <- unique(paste(Dataset.annual.flower.strip$Nest_id, Dataset.annual.flower.strip$Breeding_season_d))
Dataset.annual.flower.strip$Weighting_factor_analysis <- rep(NA, length(Dataset.annual.flower.strip$Nest_id))
for(i in Unique.observations){
  w <- which(paste(Dataset.annual.flower.strip$Nest_id, Dataset.annual.flower.strip$Breeding_season_d) == i)
  Dataset.annual.flower.strip$Weighting_factor_analysis[w] <- length(Dataset.annual.flower.strip$Weighting_factor_analysis)/length(Unique.observations)/length(w)}


#Check for correlation of predictor variables
Correlations_Annual_flower_strip <- Dataset.annual.flower.strip[,c("Year", "Breeding_season_d", "Annual_flower_strip_percentage")]
Correlations_Annual_flower_strip$Year[Correlations_Annual_flower_strip$Year == "2018"] <- 1
Correlations_Annual_flower_strip$Year[Correlations_Annual_flower_strip$Year == "2019"] <- 0
Correlations_Annual_flower_strip$Year <- as.numeric(Correlations_Annual_flower_strip$Year)
cor(Correlations_Annual_flower_strip)


#Run GLMM
Model.annual.flower.strip <- glmer(Foraging_location_annual_flower_strip ~ Breeding_season_d + Annual_flower_strip_percentage + Year + (1|Nest_id), family = "binomial"(link = "logit"), weights = Weighting_factor_analysis, data = Dataset.annual.flower.strip)
summary(Model.annual.flower.strip)




#MODEL: FIELD PATH

#Create dataset
Dataset.field.path <- subset(Dataset.GLMM, subset = Dataset.GLMM$Field_path_percentage > 0)
Dataset.field.path$Foraging_location_field_path <- ifelse(Dataset.field.path$Habitat_foraging_location == "field_path", 1, 0)


#Assign equal weights to nests per day of observation
Unique.observations <- unique(paste(Dataset.field.path$Nest_id, Dataset.field.path$Breeding_season_d))
Dataset.field.path$Weighting_factor_analysis <- rep(NA, length(Dataset.field.path$Nest_id))
for(i in Unique.observations){
  w <- which(paste(Dataset.field.path$Nest_id, Dataset.field.path$Breeding_season_d) == i)
  Dataset.field.path$Weighting_factor_analysis[w] <- length(Dataset.field.path$Weighting_factor_analysis)/length(Unique.observations)/length(w)}


#Check for correlation of predictor variables
Correlations_Field_path <- Dataset.field.path[,c("Year", "Breeding_season_d", "Field_path_percentage")]
Correlations_Field_path$Year[Correlations_Field_path$Year == "2018"] <- 1
Correlations_Field_path$Year[Correlations_Field_path$Year == "2019"] <- 0
Correlations_Field_path$Year <- as.numeric(Correlations_Field_path$Year)
cor(Correlations_Field_path)


#Run GLMM
Model.field.path <- glmer(Foraging_location_field_path ~ Breeding_season_d + Field_path_percentage + Year + (1|Nest_id), family = "binomial"(link = "logit"), weights = Weighting_factor_analysis, nAGQ = 0, data = Dataset.field.path)
summary(Model.field.path)

